# -*- coding: utf-8 -*-
from __future__ import division
from __future__ import print_function
from __future__ import absolute_import
from __future__ import unicode_literals


CHECKS = [

    # Head
    'blank-header',
    'duplicate-header',
    'non-matching-header',
    'extra-header',
    'missing-header',

    # Body
    'blank-row',
    'duplicate-row',
    'extra-value',
    'missing-value',
    'required-constraint',
    'pattern-constraint',
    'non-castable-value',
    'unique-constraint',
    'enumerable-constraint',
    'minimum-constraint',
    'maximum-constraint',
    'minimum-length-constraint',
    'maximum-length-constraint',

]
